.. _support:

Support
=======

If you have questions or issues about Niquests, there are several options:

Stack Overflow
--------------

If your question does not contain sensitive (possibly proprietary)
information or can be properly anonymized, please ask a question on
`Stack Overflow <https://stackoverflow.com/questions/tagged/python-requests>`_
and use the tag ``python-niquests``.


File an Issue
-------------

If you notice some unexpected behaviour in Niquests, or want to see support
for a new feature,
`file an issue on GitHub <https://github.com/jawah/niquests/issues>`_.
